package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0D```````````(`/@`!````8")```````!``````````%#!````
M`````````$``.``(`$``'0`<``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````=`````````!T``````````0`````````!````
M!0````````````````!``````````$```````,Q?````````S%\`````````
M`"````````$````&`````&``````````8&````````!@8```````)&``````
M``#@9```````````(````````@````8````H8````````"A@8```````*&!@
M``````#P`0```````/`!````````"``````````$````!````"`"````````
M(`)````````@`D```````$0`````````1``````````$`````````%#E=&0$
M````&%H````````86D```````!A:0```````Y`````````#D``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB+VQD+6MF<F5E8G-D+7@X-BTV-"YS;RXQ
M``````0````0`````0```$=.50`#````"```````````````!````!0````#
M````1TY5`%:&1!G(TH1_WH8J(^&&%L.6[9BG`````&$```!C````````````
M````````&```````````````-0`````````(````&P```!H`````````/@``
M`#H```!2`````````!$```!$````10```$````!6````0@````<````[````
M```````````V````6````#D``````````````$D```!0````3````#@`````
M````8@```$@````2````,0`````````,`````````"D`````````0P```$<`
M`````````````%P````S`````0```!<``````````````$\````A````-P``
M`#T```````````````L`````````)@``````````````/P`````````N````
M(````!P````D````5````%\``````````````%D```!+````*````"<````\
M````+0```#(`````````6@```````````````````%L```!*`````````"H`
M``!1````!0```"(```!3````!@``````````````````````````````````
M````````````````````````````"0````````!=````````````````````
M````````````````"@````````!A```````````````4`````````%<`````
M```````````````/````'@```!``````````7@```!,`````````%@```%4`
M``!!````30`````````E`````````````````````````"P````5````+P``
M`````````````````````````````````!T``````````````$8````C````
M```````````$```````````````````````````````T````'P````T`````
M```````````````9`````````&``````````*P``````````````,`````(`
M``````````````````!.```````````````````````````````.````````
M``,``````````````!$```!`````!`````@````@'!``!4`$ABH"0`"0A@&H
M0B@`($D@!`NXHCA-.@0&"D````!!````10```$H```!+````4@```%0```!6
M````60```%L`````````70```&``````````80``````````````>_!*:V[%
MWQ_JT^\.SMY'+6M_FGPNQ9NV(/_D#GQ!CL6XC?$.U634?-EQ6!SB1\8!K$OC
MP/+;TQVZXY)\PN4_+/JA;&"S`8MO:@E#UH?YG(%FK\QFQ;F<0$)%U>S$B060
M.?*+'`P4XI[)U;)QVLWCGC-BV^T,.I<+5J2;EJ?=HVM_J9R;"HH05Z/@^TD`
M```````````````````````````````'`P``$@``````````````````````
M``"E`@``$@`````````````````````````V`P``$@``````````````````
M```````.`P``$@````````````````````````#E`0``$@``````````````
M```````````3`@``$@````````````````````````")`@``$@``````````
M``````````````!7`@``$@````````````````````````!I`@``$@``````
M``````````````````"L`@``$@````````````````````````"=````$@``
M```````````````````````H`P``$@````````````````````````!Y````
M$@````````````````````````#S````$@````````````````````````">
M`@``$@````````````````````````!Q`@``$@``````````````````````
M``!<`0``$@````````````````````````!'`@``$@``````````````````
M```````6`P``$@`````````````````````````<`0``$@``````````````
M``````````"K````$@````````````````````````"F`0``$@``````````
M``````````````!#`0``$@````````````````````````!/`@``$@``````
M```````````````````P`@``$@````````````````````````"3`0``$@``
M``````````````````````#Q`0``$@````````````````````````#:`@``
M$@````````````````````````#'`@``$@`````````````````````````J
M`0``$@````````````````````````!@`@``$@``````````````````````
M```-`@``$@`````````````````````````1````(```````````````````
M``````#2`@``$@````````````````````````!"````$@``````````````
M``````````"S`@``$@`````````````````````````O`P``$@``````````
M``````````````#*````$@````````````````````````"K`P``$@``````
M``````````````````"(````$@````````````````````````#L`0``$@``
M``````````````````````!1`0``$@````````````````````````#Y`@``
M$@`````````````````````````T````$@`````````````````````````@
M`P``$@````````````````````````#X````$@``````````````````````
M``#]````$@````````````````````````#``@``$@``````````````````
M``````"(`0``$@````````````````````````#7````$@``````````````
M`````````````P``$@````````````````````````"Z`@``$@``````````
M``````````````!J`0``$@````````````````````````""`@``$@``````
M``````````````````"/`@``$@`````````````````````````@````(```
M```````````````````````Z`0``$@````````````````````````"7`@``
M$@`````````````````````````%`@``$@````````````````````````!1
M````$@````````````````````````"?`0``$@``````````````````````
M``!"`@``$@````````````````````````#D`@``$@``````````````````
M``````!X`0``$@`````=0`````````````````"T`P``$@`.`"!50```````
M<`````````""`P``$@`/`,A60`````````````````#9`P``$@`.`-!&0```
M````?0H```````!#`P``$@`.`%`@0```````#@(```````"(`P``$@`.`+!`
M0````````P`````````G!```$@`.`,!`0```````J0$```````!4!```$@`.
M`)!50```````.@`````````A!```$@`,`"@<0`````````````````!P!```
M$@`.`%!10```````Q`,```````!G`P``$`#Q_R3`8`````````````````#`
M`P``$@`.`'!"0```````)0````````#S`P``$0`0`-A60```````!```````
M``"Q`0``$0`:`&#`8```````$P````````!S`P``$`#Q_^#$8```````````
M```````?!```$@`.`#!`0```````*@`````````T!```$@`.`,!%0```````
M"0$```````!&!```$@`.`$!%0```````2`````````#F`P``$``9`$!D8```
M``````````````!H````$@```+`?0`````````````````#-`P``$@`.`*!"
M0```````S@````````!(`P``$0`:`$#`8```````"`````````!@`P``$`#Q
M_R3`8`````````````````!)`P``(0`:`$#`8```````"`````````#R`@``
M$0`:`'C`8```````"`````````!X`P``$@`.`/!50````````@`````````)
M`0``$@```/`>0``````````````````"!```$@`.``!60```````B0``````
M``#L`P``$@`.`&`B0`````````````````#H`P``(``9`$!D8```````````
M``````#H````$0`:`$C`8```````!`````````!*`P``(0`:`$#`8```````
M"`````````"9`P``$@`.`)!%0```````)`````````"]````$0`:`%#`8```
M`````0`````````2!```$@`.`'!#0```````RP$`````````;&EB<&5R;"YS
M;RXU+C$T`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E<D-L87-S97,`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7W-A=F5?9&5S=')U8W1O
M<E]X`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A
M:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!0
M3%]D;U]U;F1U;7``4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?
M=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL
M;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E
M<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?
M9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES
M;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB9&PN<V\N,@!L
M:6)M+G-O+C$`;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!R96%D`'!T:')E861?
M9V5T<W!E8VEF:6,`;'-E96LV-`!C;&]S90!?7V5R<FYO7VQO8V%T:6]N`&QI
M8F,N<V\N,"XQ`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W!R:6YT9@!S=')N
M8VUP`%]?<W1R9'5P`&-L;W-E9&ER`'-T<FYC<'D`7U]S=&%C:U]C:&M?9F%I
M;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!G971P:60`<W1R=&]K`'-T<FQE;@!M
M96US970`<W1R<W1R`')M9&ER`&UE;6-P>0!?7VQX<W1A=#8T`&]P96YD:7(`
M7U]X<W1A=#8T`%]?8W1Y<&5?8E]L;V,`<W1D97)R`&=E='5I9`!E>&5C=G``
M<W1R8VAR`&9P<FEN=&8`<F5A9&1I<C8T`&UE;6UO=F4`86-C97-S`'-T<F-M
M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`;&EB8W)Y<'0N<V\N,0!?
M961A=&$`7U]B<W-?<W1A<G0`7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U
M<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE
M86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?
M9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!?7VQI8F-?8W-U7VEN:70`<&%R
M7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P
M871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+
M`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C,`1TQ)0D-?,BXS+C(`
M1TQ)0D-?,BXT`````@`"``(``@`#``,``@`"``(``@````(```````(`!```
M``(``@````````````(`!0````,``@`"`````@`#`````@````(``@````(`
M```#`````@````(``@````(```````(``@````(``@```````@`#`````@`"
M``(````!``$``0`!``$``0`!``$``0`!``$``0````$``0`!``$``0````$`
M`@`!``(``@`!`````0`!``$````"``$````!```````!``$`U0$``!`````@
M````$VEI#0```P"&!`````````$``P`D`@``$`````````!R&6D)```%`)`$
M```0````%&EI#0``!`"<!```$````!-I:0T```(`A@0````````88F``````
M``8````A``````````````!`P&````````4```!5``````````````!(P&``
M``````4```!>``````````````!0P&````````4```!A``````````````!@
MP&````````4```!-``````````````!XP&````````4```!8````````````
M``!`8F````````<````!``````````````!(8F````````<````"````````
M``````!08F````````<````#``````````````!88F````````<````$````
M``````````!@8F````````<````%``````````````!H8F````````<````&
M``````````````!P8F````````<````'``````````````!X8F````````<`
M```(``````````````"`8F````````<````)``````````````"(8F``````
M``<````*``````````````"08F````````<````+``````````````"88F``
M``````<```!```````````````"@8F````````<````,``````````````"H
M8F````````<````-``````````````"P8F````````<````.````````````
M``"X8F````````<````/``````````````#`8F````````<````0````````
M``````#(8F````````<````1``````````````#08F````````<````2````
M``````````#88F````````<````3``````````````#@8F````````<````4
M``````````````#H8F````````<````5``````````````#P8F````````<`
M```6``````````````#X8F````````<````7````````````````8V``````
M``<````8```````````````(8V````````<````9```````````````08V``
M``````<````:```````````````88V````````<````;```````````````@
M8V````````<````<```````````````H8V````````<````=````````````
M```P8V````````<````>```````````````X8V````````<````?````````
M``````!`8V````````<````@``````````````!(8V````````<````B````
M``````````!08V````````<````C``````````````!88V````````<````D
M``````````````!@8V````````<````E``````````````!H8V````````<`
M```F``````````````!P8V````````<````G``````````````!X8V``````
M``<````H``````````````"`8V````````<````I``````````````"(8V``
M``````<````J``````````````"08V````````<```!:``````````````"8
M8V````````<````K``````````````"@8V````````<````L````````````
M``"H8V````````<````M``````````````"P8V````````<````N````````
M``````"X8V````````<````O``````````````#`8V````````<````P````
M``````````#(8V````````<````Q``````````````#08V````````<````R
M``````````````#88V````````<````S``````````````#@8V````````<`
M```T``````````````#H8V````````<````U``````````````#P8V``````
M``<```!3``````````````#X8V````````<````V````````````````9&``
M``````<````W```````````````(9&````````<````Y```````````````0
M9&````````<````Z```````````````89&````````<````[````````````
M```@9&````````<````\```````````````H9&````````<````]````````
M```````P9&````````<````^```````````````X9&````````<````_````
M``````````!(@^P(Z%\&``#HZ@8``.A5.@``2(/$",/_->I%(`#_)>Q%(``/
M'T``_R7J12``:`````#IX/____\EXD4@`&@!````Z=#_____)=I%(`!H`@``
M`.G`_____R7212``:`,```#IL/____\ERD4@`&@$````Z:#_____)<)%(`!H
M!0```.F0_____R6Z12``:`8```#I@/____\ELD4@`&@'````Z7#_____):I%
M(`!H"````.E@_____R6B12``:`D```#I4/____\EFD4@`&@*````Z4#_____
M)9)%(`!H"P```.DP_____R6*12``:`P```#I(/____\E@D4@`&@-````Z1#_
M____)7I%(`!H#@```.D`_____R5R12``:`\```#I\/[___\E:D4@`&@0````
MZ>#^____)6)%(`!H$0```.G0_O___R5:12``:!(```#IP/[___\E4D4@`&@3
M````Z;#^____)4I%(`!H%````.F@_O___R5"12``:!4```#ID/[___\E.D4@
M`&@6````Z8#^____)3)%(`!H%P```.EP_O___R4J12``:!@```#I8/[___\E
M(D4@`&@9````Z5#^____)1I%(`!H&@```.E`_O___R4212``:!L```#I,/[_
M__\E"D4@`&@<````Z2#^____)0)%(`!H'0```.D0_O___R7Z1"``:!X```#I
M`/[___\E\D0@`&@?````Z?#]____)>I$(`!H(````.G@_?___R7B1"``:"$`
M``#IT/W___\EVD0@`&@B````Z<#]____)=)$(`!H(P```.FP_?___R7*1"``
M:"0```#IH/W___\EPD0@`&@E````Z9#]____);I$(`!H)@```.F`_?___R6R
M1"``:"<```#I</W___\EJD0@`&@H````Z6#]____):)$(`!H*0```.E0_?__
M_R6:1"``:"H```#I0/W___\EDD0@`&@K````Z3#]____)8I$(`!H+````.D@
M_?___R6"1"``:"T```#I$/W___\E>D0@`&@N````Z0#]____)7)$(`!H+P``
M`.GP_/___R5J1"``:#````#IX/S___\E8D0@`&@Q````Z=#\____)5I$(`!H
M,@```.G`_/___R521"``:#,```#IL/S___\E2D0@`&@T````Z:#\____)4)$
M(`!H-0```.F0_/___R4Z1"``:#8```#I@/S___\E,D0@`&@W````Z7#\____
M)2I$(`!H.````.E@_/___R4B1"``:#D```#I4/S___\E&D0@`&@Z````Z4#\
M____)1)$(`!H.P```.DP_/___R4*1"``:#P```#I(/S___\E`D0@`&@]````
MZ1#\____)?I#(`!H/@```.D`_/___R7R0R``:#\```#I\/O__U-(@^P@B7PD
M'$B)="002(U\)!Q(B50D"$B-="002(U4)`CH^?W__[KP'D``O[`?0`!(B=;H
M1S4``(`]P)\@``!U+^@9_?__2(7`2(D%-Z0@``^$G`$``$B)Q^AQ_/__BSV3
MGR``Z$;]___&@#P$````BSV!GR``Z#3]__^`B*L$```"BSUOGR``Z"+]__^+
M?"0<@(BK!````8/'!4AC_TB%_P^($P$``/)(#RK'\@]8!0,Y``!F#RX%`SD`
M``^'.@$``$C!YP/HU/S__TB+?"002(D%F*,@`,<%EJ,@``0```!(BQ=(QT`(
MIEA``$C'0!"`9&``2,=`&*E80`!(B1"+5"0<@_H!?BJ-2OY,C03-"````#')
M9BX/'X0``````$B+=`\(2(ET""!(@\$(3#G!=>V-2@1(BSU+HR``@\(#13'`
MOF!`0`!(8\E(QT3(^`````!(B<'HM/W__X7`B<-T-DB+/1^C(`#HHOO__S'`
MOVI70`#H%A@``$B%P'0I2(L]`J,@`.A5^___Z##]__](@\0@B=A;PTB+/>FB
M(`#H[/W__XG#Z[I(BSW1HB``2(7_="3H%S,``.O$2(GX2(GZ2-'H@^(!2`G0
M\D@/*L#R#UC`Z=7^__^_'U=``.BN%P``2(7`2(G'2(D%D:(@`'2.Z\&_`0``
M`.CC_?__OF#`8`"_WU9``#'`Z&+\__^0D#'M28GQ2(LW2(U7"$B#Y/!05$G'
MP/!50`!(Q\$`5D``2,?'4"!``.CD^?__])"0D$B#[`A(BP5]/R``2(7`=`+_
MT$B#Q`C#D)"0D)"0D)"054B)Y5-(@^P(@#W`G2```'5+NQA@8`!(BP6ZG2``
M2('K$&!@`$C!^P-(@^L!2#G8<R1F#Q]$``!(@\`!2(D%E9T@`/\4Q1!@8`!(
MBP6'G2``2#G8<N+&!7.=(``!2(/$"%M=PV9F9BX/'X0``````$B#/?@\(```
M54B)Y702N`````!(A<!T"%V_(&!@`/_@7<.0D)"0D)"0D)"0D)"0D$%73(U'
M.#')059!54%455-(@>P(`@``9@\?A```````28L4"$B)T$B)UDC!X`A(P>88
M@^;_)0``_P!("?!(B=9(P>X(@>8`_P``2`GP2(G62,'N&('F_P```$@)\$B)
MUDC![B!(B41,B$B)\$C!YAA(P>`(@^;_)0``_P!("?!(B=9(P>HX2,'N*('F
M`/\``$@)\$@)T$B)1$R02(/!"$B#^4`/A7?___](C50DB$B-M"3P`0``2(/"
M:&8/'T0``$B+0MA(,P)(,T*H2#-"F$B)P4@!P$C!Z1]("<&#X?](B4H82(/"
M"$@Y\G743(L'2(M?($R+3PA,BU<03(M?&$B)VDR)P$@#5"2(3(G!2,'H&TC!
MX05,B=Y(`W0DD$@)R$R)P8/@_TCWT4B-K`*9>8):3(G(3(G22/?03"'*3"'1
M3"'82`G03(G*`<5,B<A(P>(>2,'H`DF)[4@)T(/@_TB)PDPAPD@)RDB)Z4R-
MI!:9>8):2(GJ2,'A!4C!ZAM,B=9(`W0DF$@)RDR)P4$!U$R)PDC!Z0)(P>(>
M2`G12(GJ@^'_2/?222'-2"'"3`GJ38GE2(VT%IEY@EI,B>))P>4%2,'J&TP)
MZDV)Y0'62(GJ2,'J`DC!Y1Y(`T0DH$@)ZDR)Y8/B_TCWU4DAU4@AS4@#3"2H
M3`GM28GU2(VL*)EY@EI(B?!)P>4%2,'H&TP)Z$F)]0'%3(G@2<'D'DC!Z`),
M">!)B?2#X/])]]1)(<5)(=1(`U0DL$T)[$F)[4Z-I"&9>8):2(GI2<'E!4C!
MZ1M,">E)B>U!`<Q(B?%(P>8>2,'I`D@)\4B)[H/A_TCWUDDAS4@AQDP)[DV)
MY4B-M#*9>8):3(GB2,'J&TG!Y05(`T0DN$P)ZDV)Y0'62(GJ2,'E'DC!Z@)(
M">I,B>6#XO](]]5)(=5((<U(`TPDP$P)[4F)]4B-K"B9>8):2(GP2<'E!4C!
MZ!M,">A)B?4!Q4R)X$G!Y!Y(P>@"3`G@28GT@^#_2??422'%22'42`-4),A-
M">Q)B>U.C:0AF7F"6DB)Z4G!Y05(P>D;3`GI28GM00',2(GQ2,'F'DC!Z0)(
M"?%(B>Z#X?](]]9((<9)(<U(`T0DT$P)[DV)Y4B-M#*9>8):3(GB2<'E!4C!
MZAM,">I-B>4!UDB)ZDC!Y1Y(P>H"2`GJ3(GE@^+_2/?522'52"'-2`-,)-A,
M">U)B?5(C:PHF7F"6DB)\$G!Y05(P>@;3`GH28GU`<5,B>!)P>0>2,'H`DP)
MX$F)](/@_TGWU$DAQ4DAU$T)[$F)[4Z-I"&9>8):2(GI2<'E!4C!Z1M,">E)
MB>U!`<Q(B?%(P>8>2,'I`D@)\4B)[H/A_T@#5"3@2/?622'-2"'&2`-$).A,
M">Y-B>5)P>4%2(VT,IEY@EI,B>)(P>H;3`GJ38GE`=9(B>I(P>4>2,'J`D@)
MZDR)Y8/B_TCWU4DAU4@AS4@#3"3P3`GM28GU2(VL*)EY@EI(B?!)P>4%2,'H
M&TP)Z$F)]0'%3(G@2<'D'DC!Z`),">!)B?2#X/])]]1)(<5)(=1-">Q)B>U.
MC:0AF7F"6DB)Z4G!Y05(P>D;3`GI28GM00',2(GQ2,'I`DC!YAY(`U0D^$@)
M\4B)[H/A_TCWUDDAS4@AQD@#!"1,">Y-B>5(C;0RF7F"6DR)XDG!Y05(P>H;
M3`GJ38GE`=9(B>I(P>4>2,'J`D@)ZDR)Y8/B_TCWU4DAU4@AS4@#3"0(3`GM
M28GU2(VL*)EY@EI(B?!)P>4%2,'H&TP)Z$F)]0'%3(G@2<'D'DC!Z`),">!)
MB?2#X/])]]1)(<5)(=1-">Q)B>U.C:0AF7F"6DB)Z4C!Z1M)P>4%2`-4)!!,
M">E)B>U!`<Q(B?%(P>8>2,'I`D@)\4B)[H/A_TCWUDDAS4@AQD@#1"083`GN
M38GE2(VT,IEY@EI,B>))P>4%2,'J&TP)ZDV)Y0'62(GJ2,'E'DC!Z@)(">I,
MB>6#XO](]]5)(=5((<U(`TPD($P)[4F)]4B-K"B9>8):2(GP2<'E!4C!Z!M,
M">A)B?4!Q4R)X$G!Y!Y(P>@"3`G@28GT@^#_2??422'422'%2`-4)"A-">Q.
MC:PAF7F"6DB)Z4F)[$G!Y`5(P>D;3`GA00'-2(GQ2,'F'DC!Z0)("?&#X?](
MB<Y(,<9(`T0D,$@Q[DR-I#*AZ]EN3(GJ3(GN2,'F!4C!ZAM("?)!`=1(B>I(
MP>4>2,'J`D@)ZH/B_TB)UD@QSD@#3"0X3#'N2(VL,*'KV6Y,B>!,B>9(P>8%
M2,'H&T@)\`'%3(GH2<'E'DC!Z`),">A)B>V#X/](B<9(,=9)P>4%2`-4)$!,
M,>9(C;0QH>O9;DB)Z4C!Z1M,">D!SDR)X4G!Y!Y(P>D"28GU3`GA2<'E!8/A
M_TF)S$DQQ$@#1"1(23'L3HVD(J'KV6Y(B?)(P>H;3`GJ00'42(GJ2,'E'DC!
MZ@)-B>5(">I)P>4%@^+_2(G52#'-2`-,)%!(,?5(C:PHH>O9;DR)X$C!Z!M,
M">@!Q4B)\$C!YAY(P>@"28GM2`GP@^#_2(G&2#'62<'E!4@#5"183#'F2(VT
M,:'KV6Y(B>E(P>D;3`GI`<Y,B>%)P>0>2,'I`DF)]4P)X4G!Y06#X?])B<Q)
M,<1(`T0D8$DQ[$Z-I"*AZ]EN2(GR2,'J&TP)ZD$!U$B)ZDC!Y1Y(P>H"38GE
M2`GJ2<'E!8/B_TB)U4@QS4@#3"1H2#'U2(VL**'KV6Y,B>!(P>@;3`GH`<5(
MB?!(P>8>2,'H`DF)[4@)\(/@_TB)QD@QUDG!Y05(`U0D<$PQYDB-M#&AZ]EN
M2(GI2,'I&TP)Z0'.3(GA2<'D'DC!Z0))B?5,">%)P>4%@^'_28G,23'$2`-$
M)'A),>Q.C:0BH>O9;DB)\DC!ZAM,">I!`=1(B>I(P>4>2,'J`DV)Y4@)ZDG!
MY06#XO](B=5(,<U(`XPD@````$@Q]4B-K"BAZ]EN3(G@2,'H&TP)Z`'%2(GP
M2,'F'DC!Z`))B>U("?"#X/](B<9(,=9)P>4%2`.4)(@```!,,>9(C;0QH>O9
M;DB)Z4C!Z1M,">D!SDR)X4G!Y!Y(P>D"28GU3`GA2<'E!8/A_TF)S$DQQ$@#
MA"20````23'L3HVD(J'KV6Y(B?)(P>H;3`GJ00'42(GJ2,'E'DC!Z@)-B>5(
M">I)P>4%@^+_2(G52#'-2`.,))@```!(,?5(C:PHH>O9;DR)X$C!Z!M,">@!
MQ4B)\$C!YAY(P>@"28GM2`GP@^#_2(G&2#'62<'E!4@#E"2@````3#'F2(VT
M,:'KV6Y(B>E(P>D;3`GI`<Y,B>%)P>0>2,'I`DF)]4P)X4G!Y06#X?])B<Q)
M,<1(`X0DJ````$DQ[$Z-I"*AZ]EN2(GR2,'J&TP)ZD$!U$B)ZDC!Y1Y(P>H"
M38GE2`GJ2<'E!8/B_TB)U4@QS4@#C"2P````2#'U2(VL**'KV6Y,B>!(P>@;
M3`GH`<5(B?!(P>8>2,'H`D@)\(/@_TB)QD@QUD@#E"2X````3#'F3(VL,:'K
MV6Y(B>E(B>Y(P>8%2,'I&T@)\4R)YDG!Y!Y(P>X"00'-3`GF@^;_2(GQ2#'!
M2`.$),````!(,>E,C:0*H>O9;DR)ZDR)Z4C!X05(P>H;2`G*2(GI2,'E'DC!
MZ0)!`=1(">F#X?](B<I(,?),,>I(C:P0H>O9;DR)X$R)XDC!X@5(P>@;2`G0
M3(GJ2<'E'@'%2,'J`KC<O!N/3`GJ28G%3`.L),@```"#XO])B=9,`>Y)B=5)
M(<Y)"<U-(>5-"?5)B>Y)`?5(B>Y)P>8%2,'N&TP)]D$!]4R)YDG!Y!Y(P>X"
M3`GF28G$3`.D)-````"#YO])B?9)(=9,`>%)B?1)"=1)(>Q-"?1-B>Y)`<Q,
MB>E)P>8%2,'I&TP)\4$!S$B)Z4C!Y1Y(P>D"2`GI2(G%2`.L)-@```"#X?])
MB<Y(`>I(B<U("?5,(>U)(?9,"?5-B>9(`=5,B>))P>8%2,'J&TP)\@'53(GJ
M2<'E'DC!Z@),">I)B<5,`ZPDX````(/B_TF)UDDASDP![DF)U4D)S4TAY4T)
M]4F)[DD!]4B)[DG!Y@5(P>X;3`GV00'U3(GF2<'D'DC![@),">9)B<1,`Z0D
MZ````(/F_TF)]DDAUDP!X4F)]$D)U$DA[$T)]$V)[DD!S$R)Z4C!Z1M)P>8%
M3`GQ00',2(GI2,'E'DC!Z0)(">E(B<5(`ZPD\````(/A_TF)SDDA]D@!ZDB)
MS4@)]4PA[4P)]4V)YD@!U4R)XDG!Y@5(P>H;3`GR`=5,B>I)P>4>2,'J`DP)
MZDF)Q4P#K"3X````@^+_28G622'.3`'N28G520G-32'E30GU28GN20'U2(GN
M2<'F!4C![AM,"?9!`?5,B>9)P>0>2,'N`DP)YDF)Q$P#I"0``0``@^;_28GV
M22'63`'A28GT20G422'L30GT38GN20',3(GI2<'F!4C!Z1M,"?%!`<Q(B>E(
MP>4>2,'I`D@)Z4B)Q4@#K"0(`0``@^'_28G.22'V2`'J2(G-2`GU3"'M3`GU
M38GF2`'53(GB2<'F!4C!ZAM,"?(!U4R)ZDG!Y1Y(P>H"3`GJ28G%3`.L)!`!
M``"#XO])B=9)(<Y,`>Y)B=5)"<U-(>5-"?5)B>Y)`?5(B>Y)P>8%2,'N&TP)
M]D$!]4R)YDG!Y!Y(P>X"3`GF28G$3`.D)!@!``"#YO])B?9)(=9,`>%)B?1)
M"=1)(>Q-"?1-B>Y)`<Q,B>E)P>8%2,'I&TP)\4$!S$B)Z4C!Y1Y(P>D"2`GI
M2(G%2`.L)"`!``"#X?])B<Y(`>I(B<U)(?9("?5,(>U,"?5-B>9(`=5,B>))
MP>8%2,'J&TP)\@'53(GJ2<'E'DC!Z@),">I)B<5,`ZPD*`$``(/B_TF)UDDA
MSDP![DF)U4D)S4TAY4T)]4F)[DD!]4B)[DG!Y@5(P>X;3`GV00'U3(GF2<'D
M'DC![@),">9)B<1,`Z0D,`$``(/F_TF)]DP!X4F)]$D)U$DA[$DAUDT)]$V)
M[DD!S$R)Z4G!Y@5(P>D;3`GQ00',2(GI2,'E'DC!Z0)(">E(B<5(`ZPD.`$`
M`(/A_TF)SDDA]D@!ZDB)S4@)]4PA[4P)]4V)YD@!U4R)XDG!Y@5(P>H;3`GR
M`=5,B>I)P>4>2,'J`DP)ZDF)Q4P#K"1``0``@^+_28G622'.3`'N28G520G-
M32'E30GU28GN20'U2(GN2,'N&TG!Y@5,"?9!`?5,B>9)P>0>2,'N`DP)YDF)
MQ$P#I"1(`0``@^;_28GV22'63`'A28GT20G422'L30GT38GN20',3(GI2<'F
M!4C!Z1M,"?%!`<Q(B>E(P>4>2,'I`D@)Z4B)Q4@#K"10`0``@^'_28G.22'V
M2`'J2(G-2`GU3"'M3`GU38GF2`'53(GB2<'F!4C!ZAM,"?(!U4R)ZDG!Y1Y(
MP>H"3`GJ28G%3`.L)%@!``"#XO](`X0D8`$``$F)UDDASDP![DF)U4D)S4@!
MP4TAY4T)]4F)[DD!]4B)[DG!Y@5(P>X;3`GV00'U3(GF2<'D'DC![@),">:#
MYO](B?!)B?1("=!)(=1((>A,">!)B>Q(P>4>3(TT`4R)Z$R)Z4C!X05(P>@;
M2<'L`D@)R$D)[$$!QKC6P6+*08/D_TB)P4@#C"1H`0``3(GU2,'E!4@!RDR)
MX4@Q\4PQZ4@!T4R)\DC!ZAM(">I,B>U)P>4>1(T\"DB)PD@#E"1P`0``2,'M
M`DP)[4R)^8/E_TC!X05(`=9(B>I,,>),,?),C2P63(GZ2,'J&T@)RDR)\4G!
MYAY!`=5(B<)(`Y0D>`$``$C!Z0),B>Y,"?%(P>8%@^'_20'42(G*2#'J3#'Z
M20'43(GJ2,'J&T@)\DB)QD$!U$@#M"2``0``3(GZ2,'J`DG!YQY-B>9,"?I)
MP>8%@^+_2`'U2(G62#'.3#'N2`'U3(GF2,'N&TP)]@'U3(GN2<'E'DC![@))
MB>Y,">Y)B<5,`ZPDB`$``(/F_TG!Y@5,`>E)B?5),=5-,>5)`<U(B>E(P>D;
M3`GQ00'-3(GA2<'D'DC!Z0)-B>Y,">%)B<1,`Z0DD`$``(/A_TP!XDF)S$DQ
M]$G!Y@5),>Q)`=1,B>I(P>H;3`GR00'42(GJ2,'E'DC!Z@)-B>9(">I(B<5(
M`ZPDF`$``(/B_TG!Y@5(`>Y(B=5(,<U,,>U(`?5,B>9(P>X;3`GV`?5,B>Y)
MP>4>2,'N`DF)[DP)[DF)Q4P#K"2@`0``@^;_2<'F!4P!Z4F)]4DQU4TQY4D!
MS4B)Z4C!Z1M,"?%!`<U,B>%(P>D"2<'D'DV)[DP)X4F)Q$P#I"2H`0``@^'_
M2<'F!4P!XDF)S$DQ]$DQ[$D!U$R)ZDC!ZAM,"?)!`=1(B>I(P>4>2,'J`DV)
MYD@)ZDB)Q4@#K"2P`0``@^+_2<'F!4@![DB)U4@QS4PQ[4@!]4R)YDC![AM,
M"?8!]4R)[DG!Y1Y(P>X"28GN3`GN28G%3`.L)+@!``"#YO],`>E)B?5),=5-
M,>5)P>8%20'-2(GI2,'I&TP)\4$!S4R)X4G!Y!Y(P>D"38GN3`GA28G$3`.D
M),`!``"#X?])P>8%3`'B28G,23'T23'L20'43(GJ2,'J&TP)\D$!U$B)ZDC!
MY1Y(P>H"38GF2`GJ2(G%2`.L),@!``"#XO])P>8%2`'N2(G52#'-3#'M2`'U
M3(GF2,'N&TP)]@'U3(GN2,'N`DG!Y1Y)B>Y,">Y)B<5,`ZPDT`$``(/F_TG!
MY@5,`>E)B?5),=5-,>5)`<U(B>E(P>D;3`GQ00'-3(GA2<'D'DC!Z0)-B>Y,
M">%)B<1,`Z0DV`$``(/A_TG!Y@5,`>))B<Q),?1),>Q)`=1,B>I(P>H;3`GR
M00'42(GJ2,'E'DC!Z@)-B>9(">I(B<5(`ZPDX`$``(/B_T@![DB)U4@QS4PQ
M[4@!]4R)YDG!Y@5(P>X;3`GV`?5,B>Y)P>4>2,'N`DF)[DP)[DF)Q4P#K"3H
M`0``@^;_2<'F!4P!Z4F)]4DQU4TQY4D!S4B)Z4C!Z1M,"?%!`<U,B>%)P>0>
M2,'I`DV)[DP)X4F)Q$P#I"3P`0``@^'_2<'F!4P!XDF)S$DQ]$DQ[$D!U$R)
MZDC!ZAM,"?)!`=1(B>I(P>4>2,'J`DV)YD@)ZDB)Q4@#K"3X`0``@^+_2<'F
M!4@#A"0``@``2`'N2(G52#'-2`'!3#'M2`'U3(GF2,'N&TP)]D2--"Y,B>Y)
MP>4>2,'N`DR)Y4P)[DV)Y4C![0*#YO])P>4>10'Q2(GP3`GM1`'>2#'000'J
M`=I,,>!-B?1(`<%,B?!)P>0%2,'H&TP)X`'(00'`3(D'3(E/"$R)5Q!(B7<8
M2(E7($B!Q`@"``!;74%<05U!7D%?PV8/'T0``$%728GW059!54F)_4%455-(
M@^P(2(7_=&U,BS40AR``387V=&$/M@<\/71TA,!T<$F)_$F#Q`%!#[8$)#P]
M=`2$P'7O12GL28L>,<!(A=MT-TUCY$R)]68/'X0``````$R)XDR)[DB)W^A2
MY/__A<!U!T*`/",]="](@\4(2(M=`$B%VW7:,<!(@\0(6UU!7$%=05Y!7\-F
M#Q^$``````!%,>3KH@\?`$PI]4J-1",!2,']`T&)+TB#Q`A;74%<05U!7D%?
MPV8N#Q^$``````!(@^P8,<!(C70D#.@@____2(/$&,-F9BX/'X0``````%-(
MB?M(@^P0#Q^$``````!(C70D##'`2(G?Z/'^__](A<!T+DAC1"0,2(L5$(8@
M`$B-!,)(BU`(2(722(D0=-!(@\`(2(M0"$B%TDB)$'7PZ[Y(@\006\,/'X0`
M`````%532(/L"(L]W(4@`.B/X___BSW1A2``2(N`0`(``$B+:`CH>>/__XL]
MNX4@``^VF#0$``#H9^/__TB+0`B#XW\/MT`@P>`'"=AFB44"BSV5A2``Z$CC
M__^+/8J%(`!(BX!``@``2(M8".@RX___,=*^H%A``$B)Q^C#X___BSUEA2``
M2(E#*.@4X___BSU6A2``2(N`0`(``$B+6`CH_N+__TB+@/`%``"+/3F%(`!(
MB4,PZ.CB__^+/2J%(`!(BX!``@``2(M8".C2XO__,=)(@[AH"0```'09BST(
MA2``Z+OB__](BX!H"0``2(N0J````(L][X0@`$B)4SCHGN+__TB+@$`"``"+
M/=F$(`!(BT`(2,=`0`````#H@.+__TB+@$`"``"+/;N$(`!(BT`(2,=`(```
M``#H8N+__XL]I(0@`$B+@$`"``!(BU@(Z$SB__](BX!0`@``2(E#2$B#Q`A;
M7<-F+@\?A```````2(EL).!(B5PDV$B)_4R)9"3H3(EL)/!,B70D^$B![+@`
M``!(A?]T!8`_`'4S2(N<))````!(BZPDF````$R+I"2@````3(NL)*@```!,
MB[0DL````$B!Q+@```###Q\`Z"OB__](A<!(B<-TP`\?`$B)W^@XX?__2(7`
M28G$#X2<````08!\)`@N#X2H````38UL)`A(B>_H\]___TR)[TF)QNCHW___
M18UT!@))8_[HF^/__TR)Z4F)Q$B)QTB)ZK[<5D``,<#HT^#__[\#````2(GB
M3(GFZ&/A__^#^/],B>=T$0^W1"00)0#P```]`$```'1RZ/7B__],B>?H7>+_
M_TB)W^BEX/__2(7`28G$#X5M____9@\?A```````2(G?Z$CA__](B>_HD.+_
M_^GX_O__#Q\`08!\)`D`#X0L____08!\)`DN#X5`____08!\)`H`#X04____
MZ2____\/'X``````Z)/^__\/'P#KB69F9F9F+@\?A```````2(E<)/!(B6PD
M^$B)^TB#[!B+/>&"(``Q[>B2X/__2(V0F````$B)WK\#````Z)[@__^%P'0:
MB>A(BUPD"$B+;"002(/$&,-F#Q^$``````"+/:*"(`#H5>#__P^W@*@````E
M`/```#T`0```=!Z+/82"(`#H-^#__P^W@*@````E`/```#T`H```=:J^`@``
M`$B)WS'MZ"7?__^%P$`/E,7KDV9F9F8N#Q^$``````!!5S'`059!54%454B)
M_5-(B?-(@^PH@#X]#Y3`2`'#2(G?Z#G>__](C70D'$&)Q4B)[S'`Z-?Z__](
MA<!)B<0/A`L!``!(B<?H$][__T2)Z3'22#G(#X/-````1(MD)!P/MD4`/#T/
MA*0!``"$P`^$G`$``$B)Z.L+#Q^``````(32=`Q(@\`!#[80@/H]=?`IZ$B+
M#:>!(`!!C7P%`DZ-).'H>>'__TB%P$F)!"0/A&,!``"+5"0<2(L%@8$@`$B+
M!-`/ME4`A-*($'0J@/H]="5(@\4!ZPT/'X0``````(#Z/702#[95`$B#P`%(
M@\4!A-*($'7IQ@`],=(/'T``#[8,$XA,$`%(@\(!A,EU\#'`2(/$*%M=05Q!
M74%>05_##Q^```````^V!!-!B`042(/"`83`=-@/M@0308@$%$B#P@&$P'7@
MZ\9F#Q]$``!,BSWI@"``13'DOA````!)@S\`="5,B?@/'X0``````$B#P`A!
M@\0!2(,X`'7R08UT)`)(8_9(P>8#BST0@2``A?]T-$R)_^@TX/__2(7`28G&
M2(D%EX`@`'1L26/,2<=$S@@`````1(ED)!SIG_[__P\?@`````!(B??'!<N`
M(``!````Z$;@__](A<!)B<9T-4ECS$R)_DB)QTB-%,T`````2(E,)`CH(]__
M_TR)-3R`(`!(BTPD".NC#Q]$```QP.E[_O__N/_____I\?[__V9F9F9F9BX/
M'X0``````$B#[`B+/0Z`(`#HP=W__[GB5D``N@`=0`"^[%9``$B)QTB#Q`CI
MAM[__V8/'T0``$B#[`B+/=Y_(`#HD=W__TB)Q^BY____BSW+?R``Z'[=__]!
MN*!80`!%,<FZ4%%``$R)P;X(5T``2(G'2(/$".G,WO__9F9F+@\?A```````
M,<##9F9F9BX/'X0``````$%528GU05152(G]OQ]70`!32('L&`0``&1(BP0E
M*````$B)A"0(!```,<#H\/C__[XO````2(GO2(G#Z%#;__](A<!T-TB)[K\H
M5T``,<#H[/S__TB+E"0(!```9$@S%"4H````2(GH#X4V`0``2('$&`0``%M=
M05Q!7<-(B>_H'-O__TR)[[XU5T``08G$Z.S;__])B<5F#Q^$``````!-A>UT
MH$&`?0``N!U70`!,#T3H2(7;=!-,B>Y(B=_H#=W__X7`#X27````3(GOZ,W:
M__](8]!!@'P5_R]U&4F-5!7_#Q]$``#&`@!(@^H!@^@!@#HO=/%!C40$`3W_
M`P``#X\^____28GHN3=70`!,B>J^5EA``$B)YS'`Z(_;__^+/6%^(`#H%-S_
M_TB-D)@```!(B>:_`P```.@0W/__A<!U'HL]/GX@`.CQV___#[>`J````"4`
M\```/0"```!T%+XU5T``,?_H$MO__TF)Q>DJ____O@$```!(B>?HS=K__X7`
M==M(B>:_*%=``.BL^___2(GGZ&3:__](B<7IL/[__^CGVO__#Q^```````^V
M#TB)^(3)=!E(C5<!9I"`^2](#T3"2(/"`0^V2O^$R77M\\-F9BX/'X0`````
M`$B%_U-(B?MT)X`_`'0BZ*W9__](C50#_T@YTW(,ZS^02(/J`4@YVG1W@#HO
M=/+K);\"````Z$;=__](A<!T!6;'`"X`6\-F+@\?A```````@#HO=`E(@^H!
M2#G3<O)(.=IT/0\?1```2(/J`4@YTW,%@#HO=/)(*=HQP$B-2@)(@?D`!```
M=[Q(B=Y(@\(!O\#`8`#HE]G__[C`P&``6\.`.B]T"UN_-U=``.EPV?__OP(`
M``#HQMS__TB)PC'`2(72=(!FQP(N`$B)T%O#9I!(@^PXOSE70`!D2(L$)2@`
M``!(B40D*#'`2(L%(!4``$B)!"1(BP4=%0``2(E$)`A(BP49%0``2(E$)!!(
MBP45%0``2(E$)!@/MP41%0``9HE$)"`QP.@U]O__,<"_0E=``.@I]O__,<"_
M2E=``.@=]O__,<"_4U=``.@1]O__,<"_6E=``.@%]O__,<"_:E=``.CY]?__
M,<"_'U=``.CM]?__,<"_=E=``.CA]?__,<"_@%=``.C5]?__,<"_BE=``.C)
M]?__,<"_*%=``.B]]?__,<"_E%=``.BQ]?__,<"_G5=``.BE]?__,<"_J%=`
M`.AY]?__2(7`=`](B<:_@%=``#'`Z(7Y__\QP+^Y5T``Z%GU__](A<!T#TB)
MQK_+5T``,<#H9?G__S'`O]970`#H.?7__TB%P'0\2(G&OQ]70``QP.A%^?__
M,<"^`EA``+]:5T``Z#3Y__](BT0D*&1(,P0E*````'5:2(/$.,,/'X``````
M,<"_YE=``.CL]/__2(7`=!=(B<:_=E=``#'`Z/CX___KL68/'T0``$B-="01
MO_=70`"Y"@```/.F=9A(C70D&[]V5T``,<#HS/C__^N%Z!78__\/'T0``$B#
M[`B+!18?(`"#^/]T"4B#Q`C##Q]``#'`OW970`#H?/3__TB)PC'`2(72=`\/
MMA*$TG0(,<"`^C`/E<")!=T>(`!(@\0(PP\?A```````2(/L".AGV?__B<?H
M$-G__TB%P'0+2(L`2(/$",,/'P`QP.OT9F9F+@\?A```````059!54%428G\
M55.[#EA``$B#[$!(QP0D#EA``$C'1"0(!%A``$B-;"0(2,=$)!`16$``2,=$
M)!@'6$``2,=$)"`,6$``2,=$)"@>6$``2,=$)#``````ZR$/'X``````2(G'
MZ%C8__](A<!T4TB#Q0A(BUWX2(7;=#$QP$B)W^B<\___2(7`28G&3(GF=`6`
M.`!US$B)WS'`Z*+W__](@\4(2(M=^$B%VW7/2(/$0%M=05Q!74%>PP\?A```
M````3(GGZ-C5__],B?=)B<7HS=7__TF-?`4"Z(/9__]-B?!)B<5(B<>Y-5=`
M`$R)XKY66$``,<#HMM;__TR)[DB)WS'`Z#GW___KE0\?@`````!!5T%6055!
M5%532(G[OQ]70`!(@>QX@0``9$B+!"4H````2(F$)&B!```QP$C'1"1@-5A`
M`$C'1"1H'5=``$C'1"1P`````$C'1"0PRU=``$C'1"0XQ%=``$C'1"1`.EA`
M`$C'1"1(X5=``$C'1"100EA``$C'1"18`````$C'A"2`````*5A``$C'A"2(
M````1EA``$C'A"20`````````.AJ\O__2(7`=`F`.``/A;P#```QP.@%_O__
M2(7`28G&#X3+`P``00^V+D"$[70LZ)O8__],B?(/'X0``````$B+"$@/ONWV
M!&D(=0/&`E](@\(!#[8J0(3M=>1,C60D.+_+5T``ZQ8/'X0``````$F#Q`A)
MBWPD^$B%_W0R,<#HZ_'__TB%P$B)Q73C@#@`=-Y(B<?H1O7__X7`=-)(B>_H
MJM3__TB%P$F)Q75=9I!(BVPD8$4Q[4B%[71.@'T``$&\`0```'4FZT`/'T0`
M`$ECQ$B+;,1@2(7M#X0O`0``08/$`8!]```/A"$!``!(B>_HZ?3__X7`=-5(
MB>_H3=3__TB%P$F)Q73%3(GOZ-W3__],B?=(B<7HTM/__XVL!00$``!(8^U(
MB>_H@-?__TV)\4B)QTF)Q$&X3UA``+DW5T``3(GJOE180``QP.BMU/__OL`!
M``!,B>?HX-/__X/X_W1SBSUM=R``Z"#5__](C9"8````3(GFOP,```#H+-7_
M_X7`#X24````2(L32(L]<G<@`$R)X;X864``,<`Q[>AIT___2(N4)&B!``!D
M2#,4)2@```!(B>@/A1<(``!(@<1X@0``6UU!7$%=05Y!7\,/'T0``.A3T___
M1(L`08/X$0^$>____TB+$TB+/11W(`!,B>&^V%A``#'`,>WH"]/__^N@9@\?
MA```````13'MZ?/^__\/'X0``````(L]LG8@`.AEU/__#[>`J````"4`\```
M/0!````/A4K___^+/9!V(`#H0]3__T2+J+````#H-]7__T$YQ0^%*O___XL]
M<'8@`.@CU/__#[>`J````"7_`0``/<`!```/A0C___](B>_H)-;__[\'6$``
M2(G%,<#HU>___TB%P$B)QP^$G0$``.BDTO__2(L[2(G&Z)GV__](A<!)B<4/
MA($!``!,B>_H)=+__X/X`WXP2&/0OUU80`"Y!0```$F-=!7\\Z9U&H/X!`^$
M]`4``(/H!$B808!\!?\O#X3C!0``,<#HR?K__X7`=14Q]DR)[^@+TO__A<!!
MB<8/A2P!``"^`EA``+]V5T``,<#H7_/__^A*U?__0;F@6$``08G`N3=70`!,
MB>*^>UA``$B)[S'`,=OHJ-+__^L]9@\?1```Z,O1__^#.!%U/X/#`>@.U?__
M08G908G`N3=70`!,B>*^B5A``$B)[S'`2,<$)*!80`#H:=+__[[``0``2(GO
MZ)S1__^#^/]TMTR)Y^@/U/__2(GNOQ]70``QP.C0\O__2(GOZ(CZ___IVOW_
M_P\?`$B)QTB)1"00Z'/Z__](BT0D$$B)Q^AFT?__2(G%Z;7]__^]`0```+\I
M6$``ZQ5FD$ACQ8/%`4B+O,2`````2(7_="8QP.A6[O__2(7`=.&`.`!TW$B)
MQ^@DT?__2(7`28G&=,SI[OO__T&^+EA``.D8_/__3(LKZ7?^__^Z`@```$C'
MQN[___^)Q^@QU/__2(VT)*````"Z!@```$2)]^CLTO__@+PDH`````!U#H"\
M)*$```!##X33!```,=(Q]D2)]^CXT___2(V<)-B```!!N(FKS>]!N?[<NIA!
MNO#ATL-(QX0DH(````$C16=,B80DJ(```$R)C"2P@```2,>$)+B```!V5#(0
M3(F4),"```!(QX0DR(````````!(QX0DT(````````#'A"08@0````````\?
M`$B-M"2@````N@"```!$B??H0]+__X7`08G%#XYQ`0``2(N,),B```!)8\6+
MO"08@0``3(V\)*````"-%,%(.<I(B90DR(````^2P4C!Z!T/MLE(`8PDT(``
M`$@!A"30@```A?]T8D&_0````$B-M"2@````02G_2&/_13G]10]._4@!WTEC
MUTB)5"08Z$?2__^+A"08@0``1`'X@_A`B80D&($```^%5?___TB-O"2@@```
M12G]3(V\)*````!,`WPD&.@0UO__08/]/P^.I````$&-1<#!Z`:)PHE$)"1(
MB=!(B50D*$C!X`9)C40'0$B)1"083(GX2(L02(V\)*"```!(B1-(BU`(2(E3
M"$B+4!!(B5,02(M0&$B)4QA(BU`@2(E3($B+4"A(B5,H2(M0,$B)4S!(BU`X
M2(/`0$B)4SA(B40D$.B,U?__2(M$)!!(.T0D&'6@2(M$)"A(@\`!2,'@!DD!
MQXM$)"3WV,'@!D6-;`7`26/53(G^2(G?Z%31__]$B:PD&($``.EO_O__1(GW
MZ#_0__](BYPDR(```$R+K"30@```2(G82,'H`X/@/XU(`4ACT,:$%-B```"`
M@_DX#X]*`@``NC<```!(8\DQ]BG"2(V\#-B```!(8]+H@L[__TR)Z$B-O"2@
M@```B)PD%X$``$C!Z!A$B*PD$X$``(B$)!"!``!,B>A(P>@0B(0D$8$``$R)
MZ$C!Z`B(A"02@0``2(G82,'H&(B$)!2!``!(B=A(P>@0B(0D%8$``$B)V#';
M2,'H"(B$)!:!``#H@-3__TB+A"2@@```2(G!B(0D4X$``$C!Z1B)RHB,)%"!
M``!(B<%(P>D0B(PD48$``$B)P4B+A"2H@```2,'I"(B,)%*!``!(B<&(A"17
M@0``2,'I&(B,)%2!``!(B<%(P>D0B(PD58$``$B)P4B+A"2P@```2,'I"(B,
M)%:!``!(B<&(A"1;@0``2,'I&(B,)%B!``!(B<%(P>D0B(PD68$``$B)P4B+
MA"2X@```2,'I"(B,)%J!``!(B<&(A"1?@0``2,'I&(B,)%R!``!(B<%(P>D0
MB(PD78$``$B)P4B+A"3`@```2,'I"(B,)%Z!``!(B<&(A"1C@0``2,'I&(B,
M)&"!``!(B<%(P>D0B(PD88$``$B)P4C!Z0B(C"1B@0``Z0P````/'T``#[:4
M'%"!``!(C;Q<(($``#'`#[;2OG980`!(@\,!Z%7-__](@_L4===,C80D(($`
M`,:$)$B!````0;F@6$``N3=70`!,B>*^9UA``$B)[S'`Z"+-___IQOK__TB+
M6PA(A=L/A!#Z__](B=_H^,O__TB#^`,/AO[Y__](C70#_+]B6$``N04```#S
MIDP/1.OIY/G__TACR;H_````,?9(C;P,V(```"G"2&/2Z#C,__](C;PDH(``
M`.B;TO__2(V4)-B```"Y!P```#'`2(G7\TBKZ8_]__^`O"2B````00^%'_O_
M_X"\)*,```!##X41^___@+PDI````$@/A0/[__^`O"2E````10^%]?K__[H"
M````2,?&QO___T2)]^CESO__2(VT)*````"Z*0```$2)]^B@S?__0;F@6$``
M3(V$)*````#I]/[__P\?1```Z`/,__\/'P!!54%455-(@^P(BSWH;B``Z)O,
M__^_6E=``,:`-00```$QP.AHZ/__2(7`=`F`.#$/A(H"```QP.CC\?__BSVU
M;B``Z&C,__^Y"P```+H!````OII80`!(B<?H@<S__TB%P`^$N0```$B+0!`Q
MVTR+8"B+!0!S(`"#^`$/CI4```"]"````.LT#Q^$``````!)BW402(L%U7(@
M`$B+/"CHG,S__X7`=6B#PP&+!<=R(`!(@\4(C5,!.=!^6HL]-FX@`.CIR___
M,<F)VDR)YDB)Q^AZS?__2(7`=#5,BRA!]D4-!'6KBST-;B``Z,#+__],B>ZY
M`@```#'22(G'Z$[+__](B<;KC68/'X0``````(L%8G(@`(U0_SG:#X0W`0``
MBSW1;2``Z(3+__^Y!````+H!````OI]80`!(B<?HG<O__TB%P$B)PW0S2(M`
M$(L]HVT@`$B+*.A3R___NJ%80`!(B<=(B>[HT\K__TB+0Q!(BQCV0PY`#X4B
M`0``BSUT;2``Z"?+__^Y!````+H!````OJ970`!(B<?H0,O__TB%P$B)PW0X
M,<"_*%=``.C<YO__2(7`28G$#X2(`0``2(M#$(L]+FT@`$B+*.C>RO__3(GB
M2(G'2(GNZ&#*__^+/1)M(`#HQ<K__XL]!VT@`,:`-00```#HL\K__[\?5T``
M2,>`N`8````````QP.A\YO__2(7`2(D%8G$@``^$M````+[``0``2(G'Z"_)
M__^#^!%T$(7`=`R#^/\/'P`/A5\!``!(@\0(6UU!7$%=PP\?@`````"#^`$/
MCL#^__^[`0```&8N#Q^$``````"+/8)L(`"#PP'H,LK__TR)YDB)Q^@7R?__
M.1WI<"``?]_IB_[__V8N#Q^$``````"+/5)L(`#H!<K__TB)WDB)Q^@ZR___
MZ</^__\/'T0``(!X`0`/A'/]__]F#Q]$``#I8?W__P\?`$B+/9%P(`#HG/+_
M_TB%P$B)!9)P(``/A*<```!(BT,02(LM<7`@`$R+($'V1"0-!'1-28M\)!!(
MB>[H&<O__XG%2(M#$$B+&/9##01T4TB+4Q!(BP4_<"``B>F_F%E``$B+,#'`
MZ"[*__]F#Q]$``!(BP4A<"``3(L@Z6G^__^+/9MK(`#H3LG__[D"````2(G'
M,=),B>;HW,C__TB)Q^N6BSUY:R``Z"S)__\QTKD"````2(G>2(G'Z+K(__](
MB<+KC[]P64``Z,O)__^)P4B+!<)O(`!(BQ7+;R``O\!90`!(BS`QP.BLR?__
M9F9F+@\?A```````54B)_5-(@^P(Z'+M__\/MA!(B<.$TG0;2(U``0\?0`"`
M^B](#T382(/``0^V4/^$TG7M,<#HYN___X7`=!U(A>UT&(!]``!T$KY/6$``
M2(G?Z`K)__](.=AT!TB#Q`A;7<-(@\0(2(GO6UWI0.;__TB#[`B+/:YJ(`#H
M8<C__[[_____2(G'Z!3(__^+/99J(`#H2<C__S'2OF`Z0`!(B<=(@\0(Z4;*
M__^0D)"0D)!(BP5)#"``2(7`=`A(BPCI_,?__S')Z_>0D)"0D)"0D//#9F9F
M9F8N#Q^$``````!(B6PDV$R)9"3@2(TM[PD@`$R-)>@)(`!,B6PDZ$R)="3P
M3(E\)/A(B5PDT$B#[#A,*>5!B?U)B?9(P?T#28G7Z./%__](A>UT'#';#Q]`
M`$R)^DR)]D2)[T'_%-Q(@\,!2#GK<NI(BUPD"$B+;"003(MD)!A,BVPD($R+
M="0H3(M\)#!(@\0XPY"0D)"0D)!52(GE4TB#[`A(BP5@"2``2(/X_W09NP!@
M8``/'T0``$B#ZPC_T$B+`TB#^/]U\4B#Q`A;7<.0D$B#[`CHW\O__TB#Q`C#
M```!``(`)7,O)7,`<&5R;'AS:2YC`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO
M861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``N`%!!4E]414U0`%!!4E]04D]'
M3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`
M4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,3T)!3%]$14)5
M1P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-
M4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,24)0051(`$193$1?
M3$E"4D%265]0051(`%-(3$E"7U!!5$@`55-%4@!365-414T`+W1M<`!414U0
M1$E2`%1-4`!54T523D%-10!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S
M8V%C:&4M)7,E<P`E,#)X`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E
M<P!!4D=6`!@`<&5R;``M90`M+0``````7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("```````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E
M(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O
M(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!E>&5C=71I;VX@
M;V8@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M`````````````````````````````,!#`1L#.^0````;````*,+__P`!```X
MQO__,`4``#C)__\H`0``^-[__W@!``#(W___V`$``.C?___P`0``2.#__Q`"
M``"XX?__0`(``#CC__]H`@``Z./__X@"```8YO__V`(``$CF___P`@``F.;_
M_P@#``"HYO__(`,``%CH__]@`P``B.C__W@#``!8Z?__J`,``"CK___(`P``
M>.O__^@#``"HZ___"`0``+CL__]0!```./?__Z`$```(^___X`0``'C[__\8
M!0``N/O__U@%``#8^___<`4``.C[__^(!0```````!0``````````7I2``%X
M$`$;#`<(D`$``"0````<````(,'__Q`$````#A!&#AA*#PMW"(``/QH[*C,D
M(@````!,````1`````C(__^Z%0```$(.$(\"2`X8C@-"#B"-!$(.*(P%00XP
MA@9!#CB#!T<.P`0#F!4..$$.,$$.*$(.($(.&$(.$$(."````````%P```"4
M````>-W__\8`````0@X0CP)%#AB.`T(.((T$10XHC`5!#C"&!D$..(,'1`Y`
M`G@*#CA!#C!!#BA"#B!"#AA"#A!"#@A*"UL..$$.,$$.*$(.($(.&$(.$$(.
M"!0```#T````Z-W__Q4`````1`X@4`X(`!P````,`0``\-W__U@`````00X0
M@P)'#B`"3@X000X(+````"P!```PWO__9@$```!!#A"&`D$.&(,#1`X@`UT!
M#AA!#A!!#@@`````````)````%P!``!PW___<@$```!-@P:&!58.P`&.`HT#
MC`1Y"@X(1`L``!P```"$`0``R.#__Z,`````388"@P-$#B!U"@X(2@L`3```
M`*0!``!8X?__(0(```!"#A"/`D0.&(X#0@X@C01"#BB,!4$.,(8&1`XX@P='
M#F`#``$*#CA!#C!!#BA"#B!"#AA"#A!"#@A("P`````4````]`$``#CC__\J
M`````$0.$&$."``4````#`(``%#C__]$`````$0.$'L."``4````)`(``(CC
M__\#```````````````\````/`(``(#C__^I`0```$(.$(T"10X8C`-!#B"&
M!$D.*(,%1P[`"`)="@XH00X@00X80@X00@X(00L`````%````'P"``#PY/__
M)0``````````````+````)0"```(Y?__S@````!$#A"#`@)!"@X(2PL"3PH.
M"$$+1@H."$H+70X(````'````,0"``"HY?__RP$```!$#D`#;`$*#@A("P``
M```<````Y`(``%CG__](`````$0.$$\*#@A%"V\."````!P````$`P``B.?_
M_R0`````1`X06`H."$0+````````1````"0#``"8Y___"0$```!"#A".`D(.
M&(T#0@X@C`1$#BB&!4$.,(,&20YP`IL*#C!!#BA!#B!"#AA"#A!"#@A)"P``
M````3````&P#``!@Z/__?0H```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&
M00XX@P=/#K"#`@-/`@H..$$.,$$.*$(.($(.&$(.$$(."$8+```\````O`,`
M`)#R___$`P```$(.$(T"0@X8C`-!#B"&!$$.*(,%1`XP`T`""@XH00X@00X8
M0@X00@X(2`L`````-````/P#```@]O__<`````!!#A"&`D0.&(,#1`X@`E8*
M#AA!#A!!#@A!"T0.&$0.$$$."``````4````-`0``%CV__\Z`````$0.$'$.
M"``D````3`0```#!__\.`@```$$.$(,"1`XP`X\!"@X00PX(00L`````%```
M`'0$``!8]O__&```````````````%````(P$``!@]O__`@``````````````
M)````*0$``!8]O__B0````!1C`6&!E\.0$:#!X\"C@.-!```````````````
M````````````````````````````````````````````````````````````
M````````__________\``````````/__________````````````````````
M``$``````````0`````````!`````````,`!`````````0````````#+`0``
M``````$`````````U0$````````!`````````"0"`````````0````````!2
M`P````````P`````````*!Q````````-`````````,A60```````!```````
M``!H`D```````/7^_V\`````@`5````````%`````````,@/0```````!@``
M``````"`!D````````H`````````I@0````````+`````````!@`````````
M%0````````````````````,`````````*&)@```````"```````````&````
M````%``````````'`````````!<`````````*!9````````'`````````)@5
M0```````"`````````"0``````````D`````````&`````````#^__]O````
M`#@50```````____;P`````"`````````/#__V\`````;A1`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$AD8```````*&!@````````````````````````````5AQ`
M``````!F'$```````'8<0```````AAQ```````"6'$```````*8<0```````
MMAQ```````#&'$```````-8<0```````YAQ```````#V'$````````8=0```
M````%AU````````F'4```````#8=0```````1AU```````!6'4```````&8=
M0```````=AU```````"&'4```````)8=0```````IAU```````"V'4``````
M`,8=0```````UAU```````#F'4```````/8=0```````!AY````````6'D``
M`````"8>0```````-AY```````!&'D```````%8>0```````9AY```````!V
M'D```````(8>0```````EAY```````"F'D```````+8>0```````QAY`````
M``#6'D```````.8>0```````]AY````````&'T```````!8?0```````)A]`
M```````V'T```````$8?0```````5A]```````!F'T```````'8?0```````
MAA]```````"6'T```````*8?0```````MA]```````#&'T```````-8?0```
M````YA]```````#V'T````````8@0```````%B!````````F($```````#8@
M0```````1B!`````````````````````````````````````````````````
M`/____\`````````````````````````````````````(R$O=7-R+V)I;B]P
M97)L"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")]
M)PH@("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP
M86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@
M=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R
M:6-T.PH*(VQI;F4@,34X"@IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T
M;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q
M=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M2
M96UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E;7`["B`@("`C($1O;B=T
M(')E;6]V92!T;W!D:7(@8F5C875S92!T:&ES(&-A=7-E<R!A(')A8V4@=VET
M:"!O=&AE<B!A<'!S"B`@("`C('1H870@87)E('1R>6EN9R!T;R!S=&%R="X*
M"B`@("!I9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*
M("`@("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG('5N;&EN:VEN9R!T:&4@
M=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@("`C('1Y<&EC86QL
M>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN
M9R!S:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A;F0@97AE8W5T86)L97,@
M=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@
M("`@("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG
M97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*("`@("`@("`C($1O;B=T(&1O
M(&%N>71H:6YG(&]N(%=I;F1O=W,@8F5C875S92!O=7(@<&%R96YT('!R;V-E
M<W,@=VEL;`H@("`@("`@(",@=&%K92!C87)E(&]F(&-L96%N:6YG('1H:6YG
M<R!U<"X*"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`H@("`@
M("`@("`@("!414U03$%412`]/B`G=&UP6%A86%@G+`H@("`@("`@("`@("!$
M25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@
M("`@("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]
M/B`P+`H@("`@("`@("D["@H@("`@("`@('!R:6YT("1T;7`@(B,A+V)I;B]S
M:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PH@("!R;2`M<F8@)R1P
M87)?=&5M<"<*("`@:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"B`@
M("`@("!B<F5A:PH@("!F:0H@("!S;&5E<"`Q"B`@('@]8&5X<'(@7"1X("L@
M,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*("`@("`@
M("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@("`@("!M>2`D
M8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*
M("`@("`@("!C;&]S92`D=&UP.PH@("`@("`@('-Y<W1E;2@D8VUD*3L*("`@
M("`@("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E
M<F9O<FT@8VQE86YU<#H@*0H@("`@("`@("`@("`@+B`D=&UP+3YF:6QE;F%M
M92D["B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N86QS.CI005(Z.D)/
M3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*"B`@("!E
M=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@)$5.5GM005)?
M05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*("`@($!!4D=6(#T@
M;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]
M("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["B`@
M("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T92`D14Y6>R1??2!I
M9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV;VME9"!F<F]M(%!!
M5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@(#T^("@D7D\@/7X@
M+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@("`@("`@/3X@*"1>
M3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*
M("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<
M)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H
M*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R86-T:6YG(&)U
M;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD[
M"GL*("`@(&QO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PH*("`@(",@
M0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T82!S96-T:6]N('M[
M>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["B`@("!B
M:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E96L@7T9(+"`M."P@
M,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U;FQE<W,@)&)U
M9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ,BP@,CL*("`@
M(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C
M:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["@H@("`@
M)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C('U]?0H*("`@(",@
M17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM["B`@("!M>2`E
M<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["B`@
M("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M>2`D9G5L;&YA;64@
M/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL
M;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@
M<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@("`@("`@(&UY
M("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH
M7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!I
M9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA
M;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE;F%M92D@/2!?
M=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@(&EF("@D;W5T*2![
M"B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@
M("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U
M=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F:6QE;F%M93L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@("`@("1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*("`@("`@
M("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\
M(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@("`@("`@("`@("`C
M('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@("`@("`@("!M
M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="([
M"B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PH@("`@
M("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D
M(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@<')I
M;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@
M('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)')E<75I<F5?;&ES='LD
M9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A
M8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@("!B=68@/3X@)&)U
M9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@("`@("`@("`@("`@
M("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@('T["B`@("`@("`@
M?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@?0H@("`@(R!]?7T*
M"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@;7D@*"1S96QF+"`D
M;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@:68@<F5F("1M;V1U;&4@
M;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M92`](&1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@("`@("`@("`@;7D@
M)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T
M*2!["B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D
M+SL*("`@("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S=#L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I
M9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T=7)N.PH*("`@("`@
M("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B
M.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E
M*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL96YA;64M/GMB=69]
M.PH@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@("`@("`@("`@(')E
M='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA
M;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@
M("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D
M;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@("`@("!C;&]S92`D
M;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]P96X@;7D@)&9H+"`G
M/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I
M.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*"B`@("`@("`@
M9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L
M92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD
M;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R960@;V)J96-T
M('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E
M(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L
M<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I<F4@24\Z.D9I;&4[
M"@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@("!W:&EL92`H
M;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@
M>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF
M("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S("@D24Y#>R1F:6QE
M;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["B`@("`@("`@("`@
M(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A8FQE(&9I;&5S
M"B`@("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PH@
M("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`C(%-K:7`@
M06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z"B`@("`@("`@
M("`@("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET
M96-U<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PH@("`@?0H*
M("`@(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P
M-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*(R!]?7T*
M"B,@07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A<F=S.PIM>2`H
M)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["@ID96QE=&4@
M)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E
M(&$@<V5C=7)I='D@<')O8FQE;2D*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[
M4$%27T1%0E5'?3L*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M
M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A
M)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F
M('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@
M(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@
M=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P87(*("`@("`@
M("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("`C(&EF('1H92!A<'`@:7,@
M:6YV;VME9"!A<R`B87!P;F%M92`M+7!A<BUO<'1I;VYS("TM<F5U<V4@4%)/
M1U)!32!`4%)/1U]!4D=6(BP*("`@(",@=7-E('1H92!A<'`@=&\@<G5N('1H
M92!G:79E;B!P97)L(&-O9&4@:6YS=&5A9"!O9B!A;GET:&EN9R!F<F]M('1H
M90H@("`@(R!A<'`@:71S96QF("AB=70@<W1I;&P@<V5T('5P('1H92!N;W)M
M86P@87!P(&5N=FER;VYM96YT(&%N9"!`24Y#*0H@("`@:68@*$!!4D=6(&%N
M9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*("`@("`@("!S:&EF="!`05)'
M5CL*("`@("`@("`D14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8[
M"B`@("!]"B`@("!E;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*"B`@
M("`@("`@;7D@0&%D9%]T;U]I;F,["B`@("`@("`@=VAI;&4@*$!!4D=6*2![
M"B`@("`@("`@("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=
M*2@N*BDO(&]R(&QA<W0["@H@("`@("`@("`@("!I9B`H)#$@97$@)TDG*2![
M"B`@("`@("`@("`@("`@("!P=7-H($!A9&1?=&]?:6YC+"`D,CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@
M("`@("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<VEF("@D,2!E<2`G02<I('L*("`@("`@("`@("`@("`@('5N
M<VAI9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@("`@("`D;W5T(#T@
M)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=B
M)RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=S:71E)SL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@
M("`@("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@("`@("`@("`@
M)'%U:65T(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H
M)#$@97$@)TPG*2!["B`@("`@("`@("`@("`@("!O<&5N("1L;V=F:"P@(CX^
M(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I('L*("`@
M("`@("`@("`@("`@("1C86-H95]N86UE(#T@)#(["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@("`@(&EF("AM
M>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@("`@("`@9&5L
M971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@("`@("!I;FET7VEN
M8R@I.PH@("`@("`@("`@("`@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("`@
M("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["B`@("`@("`@("`@("`@("!E>&ET.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!U;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PH@("`@?0I]"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@<W5P<&]R="$*
M"B,@?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@>WM["FEF("@D
M;W5T*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@
M7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E
M($E/.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@
M?0H*("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD["B`@("!M>2`D>FEP.PH*
M"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!M>2`D9F@L
M("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@
M("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@
M("`@("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@("`@("!O<B!D:64@
M(E)E860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]"@H*("`@(&UY("5E;G8@
M/2!D;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^
M8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@("`@("`@)&UE=&$@/7X@
M<R\N*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M971A(#U^(',O7EQ3+BHO
M+VUS.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O
M;6<["B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P96X@:6YP=70@86YD(&]U
M='!U="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@7#0["@H@("`@:68@*&1E
M9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2+"`G/"<L("1P87(@;W(@
M9&EE("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D92A005(I.PH@("`@("`@
M(&1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q
M(")02UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A=&50871H*"1O=70I(#L*
M("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@("`@("`D;W5T
M+`H@("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]7
M4D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@("`@,#<W-RP*
M("`@("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH*("`@("0O(#T@
M*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@
M('-E96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(
M/CL*("`@(&EF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^
M("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]"B`@("!F;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@("`@;7D@)'9A;"`]("1E
M;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L(#T@979A;"`D=F%L(&EF
M("1V86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?
M4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@("`@;7D@)'-E="`](")0
M05)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@("`@("`D;&]A9&5R(#U^
M('-[)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M86=I8R`N("1S970@+B`H
M)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@("`@("`@('UE
M9SL*("`@('T*("`@("1F:"T^<')I;G0H)&QO861E<BD["B`@("`D+R`]('5N
M9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![
M>WL*("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER92!005(Z.DAE
M879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M("`@("`@("!I;FET7VEN8R@I.PH*("`@("`@("!R97%U:7)E7VUO9'5L97,H
M*3L*"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@("`@("`@("`@("!L96YG
M=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@?2!G<F5P('L*("`@("`@
M("`@("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@
M*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@("`@("`H)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@("`@("`@("`@)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@("`@("!]($!)
M3D,["@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@
M4E0@(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO;BUE>&ES=&EN9R!E;G1R
M>2!I;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U=&]S<&QI="YI
M>"X*("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@=VET:"!N;R!D
M965P97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@("`@(",@4V]M96)O9'D@
M<&QE87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W
M:&%T)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F86EL960N("TM(%-T969F
M96X*("`@("`@("!M>2`E9FEL97,["B`@("`@("`@+UY?/"@N*RDD+R!A;F0@
M+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@
M)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@("`@("`@;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@("`@("`@;7D@
M)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I
M('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D["@H@("`@("`@("`@
M("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@("`@("`@("`@(&EF
M("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@
M("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@("`@("`@("`@("`@
M("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS
M:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@("`@("`@("`@
M("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["B`@("`@("`@
M("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A
M=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@("`@("`@("`@("`@
M("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D
M,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE>'0@:68@(7)E9B@D
M9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PH@("`@("`@
M("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@("`@<7$H4&%C:VEN
M9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@
M("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@*3L*"B`@("`@("`@
M("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H<F5F*"1F:6QE*2D@
M>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@
M("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F
M:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E*$9)3$4I.PH@("`@
M("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@("`@("`@("`@("`@
M("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0H@("`@("`@
M("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE
M(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@("`@("`@("!005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4L("1N86UE*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;W5T
M<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP
M<FEN="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG
M+"!L96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*'-P<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@
M("`@*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N
M="D["B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET
M92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M
M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?
M;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C
M86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*
M("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[
M($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@
M("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S
M=#HZ340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@
M:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?
M=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P
M.PH@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?
M=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^861D9FEL
M92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS
M92!["B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD
M;W5T(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@
M("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@
M(&-L;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M93L*("`@('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG
M=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*
M("`@("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP
M86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D
M9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@
M8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]
M?0H*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[
M>PI["B`@("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@
M7V9I>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE
M(&%N9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER
M92!005(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*
M("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?
M7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ
M1FEN9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@
M(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/
M.CI&:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G
M*2!O<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O
M<B!D:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II
M<#L*("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@
M("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI
M<R!P;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM
M96UB97)S("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N
M86UE(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@("`@("`@("`O
M/W-H;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E
M<G-I;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@("`@("`@
M("`@("`@("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@("!M>2`D97AT
M<F%C=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&
M:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N
M86UE*3L*("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]
M/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@("`@("`@
M("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@
M(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@
M("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D[
M"B`@("`@("`@("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D
M7D\@97$@(FAP=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@
M("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@
M<G5N+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G
M93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@
M<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@
M6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B
M($-R96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A
M=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@
M*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*
M("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H
M*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO
M9'5L97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@
M:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E
M<75I<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E
M<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I
M<F4@=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ
M2&5A=GD["B`@("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&
M8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL
M93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E($-O
M;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E<75I<F4@24\Z
M.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER
M92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@(')E<75I<F4@
M4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!R97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0871C:$-O;G1E;G0["B`@("!R97%U:7)E(&%T=')I8G5T97,["B`@
M("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I
M;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@
M(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*("`@
M(&5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA
M<B!].PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@
M:6X@;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN
M(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T
M7W!A<E]T96UP('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E
M;7`@/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M
M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z
M7%Q414U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT('5N;&5S<R!D
M969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@
M("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C
M(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@
M(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@
M("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@
M)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.
M5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N
M86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T
M:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK9&ER
M("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y]
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@
M("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@
M("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D
M9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!
M0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@
M("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@
M("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY
M("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI3
M2$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@
M("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA
M<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@
M("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S
M=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D
M<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS
M.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G
M;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG
M97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO
M<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@
M("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T
M;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D
M8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL
M96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D
M9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@
M("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N
M86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@
M)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@
M("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV
M97,@:6X@4$%2.CI3971U<%!R;V=N86UE.CIS971?<')O9VYA;64*<W5B(%]S
M971?<')O9VYA;64@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!
M345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@
M("`@)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D
M,#L*"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M
M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@
M/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'
M3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X]
M(#`I('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE
M*2!["B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@
M("`@("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@
M("`@("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D
M9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(
M?2D@>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N
M9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<
M421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL
M(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@
M("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92([
M"B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N
M86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G
M;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@
M("`C(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]
M("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@
M("`@("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P
M=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D
M14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R
M;CL*("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:141]
M(#T@,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@("`@
M("!D96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!
M4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A
M;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@("`@
M:68@*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,
M3T)!3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A
M<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[
M4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K
M*2\["B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I970[
M"B`@("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN
M(CL*("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@
M('T*?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*
M(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K
M86=E(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ
M9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R
M+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S
M=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N
M86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ
M7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q,0H*7U]%3D1?7PH`
M````1T-#.B`H1&5B:6%N(#0N-BXR+34I(#0N-BXR`$=#0SH@*$1E8FEA;B`T
M+C0N-BTQ,"D@-"XT+C8``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT
M86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS
M='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L
M82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R
M`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N
M9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````````
M````````````````````````````````````````````````````````````
M``````````L````!`````@```````````D`````````"````````'0``````
M``````````````$````````````````````3````!P````(`````````(`)`
M```````@`@```````"`````````````````````$````````````````````
M(0````<````"`````````$`"0```````0`(````````D````````````````
M````!````````````````````#@````%`````@````````!H`D```````&@"
M````````&`,````````&``````````@`````````!``````````T````]O__
M;P(`````````@`5```````"`!0`````````!````````!@`````````(````
M````````````````/@````L````"`````````(`&0```````@`8```````!(
M"0````````<````!````"``````````8`````````$8````#`````@``````
M``#(#T```````,@/````````I@0```````````````````$`````````````
M``````!.````____;P(`````````;A1```````!N%````````,8`````````
M!@`````````"``````````(`````````6P```/[__V\"`````````#@50```
M````.!4```````!@``````````<````"````"````````````````````&H`
M```$`````@````````"8%4```````)@5````````D``````````&````````
M``@`````````&`````````!T````!`````(`````````*!9````````H%@``
M```````&````````!@````T````(`````````!@`````````?@````$````&
M`````````"@<0```````*!P````````8````````````````````!```````
M`````````````'D````!````!@````````!`'$```````$`<````````$`0`
M`````````````````!``````````$`````````"$`````0````8`````````
M4"!```````!0(````````'@V```````````````````0````````````````
M````B@````$````&`````````,A60```````R%8````````.````````````
M````````!````````````````````)`````!`````@````````#85D``````
M`-A6````````0`,```````````````````@```````````````````"8````
M`0````(`````````&%I````````86@```````.0````````````````````$
M````````````````````I@````$````"``````````!;0````````%L`````
M``#,!```````````````````"````````````````````+`````!`````P``
M````````8&````````!@````````$`````````````````````@`````````
M``````````"W`````0````,`````````$&!@```````08````````!``````
M```````````````(````````````````````O@````$````#`````````"!@
M8```````(&`````````(````````````````````"```````````````````
M`,,````&`````P`````````H8&```````"A@````````\`$````````'````
M``````@`````````$`````````#,`````0````,`````````&&)@```````8
M8@```````!`````````````````````(``````````@`````````T0````$`
M```#`````````"AB8```````*&(````````8`@``````````````````"```
M```````(`````````-H````!`````P````````!`9&```````$!D````````
MY%L``````````````````"````````````````````#@````"`````,`````
M````0,!@```````DP````````*`$```````````````````@````````````
M````````Y0````$````P````````````````````),`````````Y````````
M`````````````0`````````!``````````$````#````````````````````
L`````%W`````````[@````````````````````$`````````````````````
